#
# spec file for package python-pyperf
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pyperf
Version:        2.6.3
Release:        1.2
Summary:        Python module to run and analyze benchmarks
License:        MIT
URL:            https://github.com/vstinner/pyperf
Source:         https://files.pythonhosted.org/packages/source/p/pyperf/pyperf-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python-psutil
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Python module to run and analyze benchmarks.

%prep
%setup -q -n pyperf-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/pyperf
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative pyperf

%postun
%python_uninstall_alternative pyperf

%files %{python_files}
%doc README.rst
%license COPYING
%python_alternative %{_bindir}/pyperf
%{python_sitelib}/*

%changelog
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 2.6.3:
  * Support Free-threading CPython (PEP-703) by disabling psutil
    related features.
  * Fix mem_max_rss measurement on macOS.
* Sun Jan  7 2024 Dirk Müller <dmueller@suse.com>
- update to 2.6.2:
  * Now, pystats stats are collected during warmups.
  * system: Fix detection of battery.
  * Fix a possible attribute error in argument parsing.
  * Inherit PYTHONPATH environment variable by default.
  * Runner.bench_async_func() takes an optional loop_factory to
    support custom loop construction.
* Wed Nov  9 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2.5.0
  * Recognize new name of Graal-based Python as jitted by @timfel in #139
  * Collect specialization statistics from running benchmarks by @mdboom in #140
  * Add support for Python 3.11 by @hugovk in #142
* Thu Oct  6 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- version update to 2.4.1
  * Reject --tracemalloc in pyperf command by @oraluben in #131
* Thu Apr  7 2022 pgajdos@suse.com
- version update to 2.3.1
  Version 2.3.1 (2022-02-03)
  - -------------------------
  * Add a ``Runner.bench_async_func()`` to benchmark an asyncio coroutine.
    Patch by Inada Naoki.
  * pyperf now recognizes graalpython as the JIT-based implementation.
    Patch by Tim Felgentreff.
  Version 2.3.0 (2021-09-28)
  - -------------------------
  * pyperf ref:`compare_to command <compare_to_cmd>` now supports the
    ``--table-format`` option which can designate the table format
    between reST and markdown.
  Version 2.2.0 (2021-03-24)
  - -------------------------
  * ``--track-memory`` option now supports macOS by using ``psutil``.
  * Added ``--copy-env`` command line option that inherits all environment variables.
  * The development branch ``master`` was renamed to ``main``.
    See https://sfconservancy.org/news/2020/jun/23/gitbranchname/ for the
    rationale.
  Version 2.1.0 (2021-01-14)
  - -------------------------
  * The :ref:`compare_to command <compare_to_cmd>` now computes the geometric
    mean.
  * The :ref:`compare_to command <compare_to_cmd>` no longer displays
    percentages: display less numbers to make the output easier to read. Also,
    percentage were almost the same values than the xxx faster or xxx slower
    values, but rounded differenly which introduced confusion.
  * Project moved to https://github.com/psf/pyperf/
  * system command now only emits a warning rather than failing with a hard error
    if it fails to get or set the frequency of a CPU.
  * The pyperf project is now covered by the `PSF Code of Conduct
    <https://www.python.org/psf/codeofconduct/>`_.
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Fri Mar 20 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 2.0.0
  * Drop Python 2 support. Use pyperf 1.7.1 if you still need Python 2.7
    support.
  * Remove ``python_unicode`` metadata.
  * pyperf.perf_counter() is now deprecated: use time.perf_counter() directly.
  * Support Python 3.8: ``time.clock()`` no longer exists.
- Drop no longer needed patches python-retcode.patch and python38.patch
* Mon Mar  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add patches to work with py3.8:
  * python-retcode.patch
  * python38.patch
* Mon Mar  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.7.0:
  * metadata: add ``python_compiler``
  * Windows: inherit ``SystemDrive`` environment variable by default.
  * Fix tests on ARM and PPC: cpu_model_name metadata is no longer required
    on Linux.
  * tests: Do not allow test suite to execute without unittest2 on Python2,
    otherwise man failures occur due to missing 'assertRegex'.
  * doc: Update old/dead links.
  * Travis CI: drop Python 3.4 support.
* Sat Oct 12 2019 John Vandenberg <jayvdb@gmail.com>
- Fixed execution of test suite, skipping test_collect_metadata
- Fixed Python 2 runtime dependencies and recommends psutil
* Thu Sep 12 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.6.1
